Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(79)

Unified Diff: content/public/browser/browser_child_process_host_delegate.h

Issue 9235052: Fix race condition in utility process clients (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/browser_child_process_host_delegate.h
diff --git a/content/public/browser/browser_child_process_host_delegate.h b/content/public/browser/browser_child_process_host_delegate.h
index e028c9af34ba672a5c5e6434796327dfb6548312..c8b82d07f233dddf270f1866fb23845bf28ca0b8 100644
--- a/content/public/browser/browser_child_process_host_delegate.h
+++ b/content/public/browser/browser_child_process_host_delegate.h
@@ -26,10 +26,10 @@ class CONTENT_EXPORT BrowserChildProcessHostDelegate
// Called when the process has been started.
virtual void OnProcessLaunched() {}
- // Called if the process crashed. |exit_code| is the status returned when the
- // process crashed (for posix, as returned from waitpid(), for Windows, as
- // returned from GetExitCodeProcess()).
- virtual void OnProcessCrashed(int exit_code) {}
+ // Called if the process crashed or was killed. |exit_code| is the status
+ // returned when the process crashed (for posix, as returned from waitpid(),
+ // for Windows, as returned from GetExitCodeProcess()).
+ virtual void OnProcessCrashedOrWasKilled(int exit_code) {}
};
}; // namespace content
« content/browser/utility_process_host.h ('K') | « content/browser/utility_process_host.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698